@@ -51,15 +51,10 @@ using namespace ::std;
 #endif /* NO_NAMESPACES */
 
 //------------------------------------------------------------------------
-void Binc::MimePart::printBody(int fd, IODevice &output,
+void Binc::MimePart::printBody(IODevice &output,
 			       unsigned int startoffset,
 			       unsigned int length) const
 {
-  if (!mimeSource || mimeSource->getFileDescriptor() != fd) {
-    delete mimeSource;
-    mimeSource = new MimeInputSource(fd);
-  }
-
   mimeSource->reset();
   mimeSource->seek(bodystartoffsetcrlf + startoffset);
 
@@ -75,18 +70,6 @@ void Binc::MimePart::printBody(int fd, IODevice &output,
   }
 }
 
-void Binc::MimePart::getBody(int fd, string &s,
-			     unsigned int startoffset,
-			     unsigned int length) const
-{
-
-  if (!mimeSource || mimeSource->getFileDescriptor() != fd) {
-    delete mimeSource;
-    mimeSource = new MimeInputSource(fd);
-  }
-  getBody(s, startoffset, length);
-}
-
 void Binc::MimePart::getBody(string &s,
 			     unsigned int startoffset,
 			     unsigned int length) const
