@@ -47,25 +47,17 @@
 #include "execmd.h"
 #include "extrameta.h"
 
-// When using extended attributes, we have to use the ctime, because
-// this is all that gets set when the attributes are modified. 
-// As of 1.19 we use ctime in all cases as this allows to detect a
-// file renamed into an existing file (e.g. when shifting logs or
-// other archives).
-#ifdef RCL_USE_XATTR
-#define RCL_STTIME st_ctime
-#else
-#define RCL_STTIME st_ctime
-#endif // RCL_USE_XATTR
-
 using namespace std;
 
 #ifdef IDX_THREADS
 class DbUpdTask {
 public:
+    // Take some care to avoid sharing string data (if string impl is cow)
     DbUpdTask(const string& u, const string& p, const Rcl::Doc& d)
-	: udi(u), parent_udi(p), doc(d)
-    {}
+	: udi(u.begin(), u.end()), parent_udi(p.begin(), p.end())
+    {
+        d.copyto(&doc);
+    }
     string udi;
     string parent_udi;
     Rcl::Doc doc;
@@ -74,10 +66,13 @@ extern void *FsIndexerDbUpdWorker(void*);
 
 class InternfileTask {
 public:
+    // Take some care to avoid sharing string data (if string impl is cow)
     InternfileTask(const std::string &f, const struct stat *i_stp,
 		   map<string,string> lfields)
-	: fn(f), statbuf(*i_stp), localfields(lfields)
-    {}
+	: fn(f.begin(), f.end()), statbuf(*i_stp)
+    {
+        map_ss_cp_noshr(lfields, &localfields);
+    }
     string fn;
     struct stat statbuf;
     map<string,string> localfields;
@@ -104,7 +99,8 @@ public:
 
 FsIndexer::FsIndexer(RclConfig *cnf, Rcl::Db *db, DbIxStatusUpdater *updfunc) 
     : m_config(cnf), m_db(db), m_updater(updfunc), 
-      m_missing(new FSIFIMissingStore), m_detectxattronly(false)
+      m_missing(new FSIFIMissingStore), m_detectxattronly(false),
+      m_noretryfailed(false)
 #ifdef IDX_THREADS
     , m_iwqueue("Internfile", cnf->getThrConf(RclConfig::ThrIntern).first), 
       m_dwqueue("Split", cnf->getThrConf(RclConfig::ThrSplit).first)
@@ -113,7 +109,7 @@ FsIndexer::FsIndexer(RclConfig *cnf, Rcl::Db *db, DbIxStatusUpdater *updfunc)
     LOGDEB1(("FsIndexer::FsIndexer\n"));
     m_havelocalfields = m_config->hasNameAnywhere("localfields");
     m_config->getConfParam("detectxattronly", &m_detectxattronly);
-
+    
 #ifdef IDX_THREADS
     m_stableconfig = new RclConfig(*m_config);
     m_loglevel = DebugLog::getdbl()->getlevel();
@@ -177,8 +173,10 @@ bool FsIndexer::init()
 }
 
 // Recursively index each directory in the topdirs:
-bool FsIndexer::index(bool quickshallow)
+bool FsIndexer::index(int flags)
 {
+    bool quickshallow = (flags & ConfIndexer::IxFQuickShallow) != 0;
+    m_noretryfailed = (flags & ConfIndexer::IxFNoRetryFailed) != 0;
     Chrono chron;
     if (!init())
 	return false;
@@ -253,29 +251,57 @@ static bool matchesSkipped(const vector<string>& tdl,
                            FsTreeWalker& walker,
                            const string& path)
 {
-    // First check what (if any) topdir this is in:
-    string td;
-    for (vector<string>::const_iterator it = tdl.begin(); 
-	 it != tdl.end(); it++) {
-        if (path.find(*it) == 0) {
-            td = *it;
-            break;
+    // Check path against topdirs and skippedPaths. We go up the
+    // ancestors until we find either a topdirs or a skippedPaths
+    // match. If topdirs is found first-> ok to index (it's possible
+    // and useful to configure a topdir under a skippedPath in the
+    // config). This matches what happens during the normal fs tree
+    // walk.
+    string canonpath = path_canon(path);
+    string mpath = canonpath;
+    string topdir;
+    while (mpath.length() > 1) {
+        for (vector<string>::const_iterator it = tdl.begin();  
+             it != tdl.end(); it++) {
+            // the topdirs members are already canonized.
+            LOGDEB2(("matchesSkipped: comparing ancestor [%s] to "
+                     "topdir [%s]\n", mpath.c_str(), it->c_str()));
+            if (!mpath.compare(*it)) {
+                topdir = *it;
+                goto goodpath;
+            }
+        }
+
+        if (walker.inSkippedPaths(mpath, false)) {
+            LOGDEB(("FsIndexer::indexFiles: skipping [%s] (skpp)\n", 
+                    path.c_str()));
+            return true;
+        }
+
+        string::size_type len = mpath.length();
+        mpath = path_getfather(mpath);
+        // getfather normally returns a path ending with /, canonic
+        // paths don't (except for '/' itself).
+        if (!mpath.empty() && mpath[mpath.size()-1] == '/')
+            mpath.erase(mpath.size()-1);
+        // should not be necessary, but lets be prudent. If the
+        // path did not shorten, something is seriously amiss
+        // (could be an assert actually)
+        if (mpath.length() >= len) {
+            LOGERR(("FsIndexer::indexFile: internal Error: path [%s] did not "
+                    "shorten\n", mpath.c_str()));
+            return true;
         }
     }
-    if (td.empty()) {
-        LOGDEB(("FsIndexer::indexFiles: skipping [%s] (ntd)\n", path.c_str()));
-        return true;
-    }
+    // We get there if neither topdirs nor skippedPaths tests matched
+    LOGDEB(("FsIndexer::indexFiles: skipping [%s] (ntd)\n", path.c_str()));
+    return true;
 
-    // Check path against skippedPaths. 
-    if (walker.inSkippedPaths(path)) {
-        LOGDEB(("FsIndexer::indexFiles: skipping [%s] (skpp)\n", path.c_str()));
-        return true;
-    }
+goodpath:
 
     // Then check all path components up to the topdir against skippedNames
-    string mpath = path;
-    while (mpath.length() >= td.length() && mpath.length() > 1) {
+    mpath = canonpath;
+    while (mpath.length() >= topdir.length() && mpath.length() > 1) {
         string fn = path_getsimple(mpath);
         if (walker.inSkippedNames(fn)) {
             LOGDEB(("FsIndexer::indexFiles: skipping [%s] (skpn)\n", 
@@ -301,9 +327,10 @@ static bool matchesSkipped(const vector<string>& tdl,
 /** 
  * Index individual files, out of a full tree run. No database purging
  */
-bool FsIndexer::indexFiles(list<string>& files, ConfIndexer::IxFlag flag)
+bool FsIndexer::indexFiles(list<string>& files, int flags)
 {
     LOGDEB(("FsIndexer::indexFiles\n"));
+    m_noretryfailed = (flags & ConfIndexer::IxFNoRetryFailed) != 0;
     int ret = false;
 
     if (!init())
@@ -331,7 +358,7 @@ bool FsIndexer::indexFiles(list<string>& files, ConfIndexer::IxFlag flag)
 
         walker.setSkippedNames(m_config->getSkippedNames());
 	// Check path against indexed areas and skipped names/paths
-        if (!(flag&ConfIndexer::IxFIgnoreSkip) && 
+        if (!(flags & ConfIndexer::IxFIgnoreSkip) && 
 	    matchesSkipped(m_tdl, walker, *it)) {
             it++; 
 	    continue;
@@ -465,7 +492,9 @@ void FsIndexer::setlocalfields(const map<string, string>& fields, Rcl::Doc& doc)
 void FsIndexer::makesig(const struct stat *stp, string& out)
 {
     char cbuf[100]; 
-    sprintf(cbuf, "%lld" "%ld", (long long)stp->st_size, (long)stp->RCL_STTIME);
+    sprintf(cbuf, "%lld" "%ld", (long long)stp->st_size, 
+            o_uptodate_test_use_mtime ? 
+            (long)stp->st_mtime : (long)stp->st_ctime);
     out = cbuf;
 }
 
@@ -623,8 +652,14 @@ FsIndexer::processonefile(RclConfig *config,
     makesig(stp, sig);
     string udi;
     make_udi(fn, cstr_null, udi);
-    bool existingDoc;
-    bool needupdate = m_db->needUpdate(udi, sig, &existingDoc);
+    unsigned int existingDoc;
+    string oldsig;
+    bool needupdate;
+    if (m_noretryfailed) {
+        needupdate = m_db->needUpdate(udi, sig, &existingDoc, &oldsig);
+    } else {
+        needupdate = m_db->needUpdate(udi, sig, &existingDoc, 0);
+    }
 
     // If ctime (which we use for the sig) differs from mtime, then at most
     // the extended attributes were changed, no need to index content.
@@ -634,7 +669,24 @@ FsIndexer::processonefile(RclConfig *config,
     // the ctime to avoid this
     bool xattronly = m_detectxattronly && !m_db->inFullReset() && 
 	existingDoc && needupdate && (stp->st_mtime < stp->st_ctime);
-    
+
+    LOGDEB(("processone: needupdate %d noretry %d existing %d oldsig [%s]\n",
+            needupdate, m_noretryfailed, existingDoc, oldsig.c_str()));
+
+    // If noretryfailed is set, check for a file which previously
+    // failed to index, and avoid re-processing it
+    if (needupdate && m_noretryfailed && existingDoc && 
+        !oldsig.empty() && *oldsig.rbegin() == '+') {
+        // Check that the sigs are the same except for the '+'. If the file
+        // actually changed, we always retry (maybe it was fixed)
+        string nold = oldsig.substr(0, oldsig.size()-1);
+        if (!nold.compare(sig)) {
+            LOGDEB(("processone: not retrying previously failed file\n"));
+            m_db->setExistingFlags(udi, existingDoc);
+            needupdate = false;
+        }
+    }
+
     if (!needupdate) {
 	LOGDEB0(("processone: up to date: %s\n", fn.c_str()));
 	if (m_updater) {
@@ -691,6 +743,11 @@ FsIndexer::processonefile(RclConfig *config,
 	    // We index at least the file name even if there was an error.
 	    // We'll change the signature to ensure that the indexing will
 	    // be retried every time.
+            
+            // If there is an error and the base doc was already seen,
+            // we're done
+            if (fis == FileInterner::FIError && hadNullIpath)
+		return FsTreeWalker::FtwOk;
 
 	    // Internal access path for multi-document files. If empty, this is
 	    // for the main file.
@@ -707,14 +764,23 @@ FsIndexer::processonefile(RclConfig *config,
 		make_udi(fn, doc.ipath, udi);
 	    }
 
-	    // Set file name, mod time and url if not done by filter
+	    // Set file name, mod time and url if not done by
+            // filter. We used to set the top-level container file
+            // name for all subdocs without a proper file name, but
+            // this did not make sense (resulted in multiple not
+            // useful hits on the subdocs when searching for the
+            // file name).
 	    if (doc.fmtime.empty())
 		doc.fmtime = ascdate;
 	    if (doc.url.empty())
 		doc.url = cstr_fileu + fn;
 	    const string *fnp = 0;
-	    if (!doc.peekmeta(Rcl::Doc::keyfn, &fnp) || fnp->empty())
-		doc.meta[Rcl::Doc::keyfn] = utf8fn;
+	    if (doc.ipath.empty()) {
+                if (!doc.peekmeta(Rcl::Doc::keyfn, &fnp) || fnp->empty())
+                    doc.meta[Rcl::Doc::keyfn] = utf8fn;
+            } 
+            // Set container file name for all docs, top or subdoc
+            doc.meta[Rcl::Doc::keytcfn] = utf8fn;
 
 	    char cbuf[100]; 
 	    sprintf(cbuf, "%lld", (long long)stp->st_size);
@@ -799,7 +865,8 @@ FsIndexer::processonefile(RclConfig *config,
 	    fileDoc.onlyxattr = true;
 	} else {
 	    fileDoc.fmtime = ascdate;
-	    fileDoc.meta[Rcl::Doc::keyfn] = utf8fn;
+	    fileDoc.meta[Rcl::Doc::keyfn] = 
+                fileDoc.meta[Rcl::Doc::keytcfn] = utf8fn;
 	    fileDoc.haschildren = true;
 	    fileDoc.mimetype = mimetype;
 	    fileDoc.url = cstr_fileu + fn;
