@@ -46,15 +46,21 @@ using namespace std;
 /// current/interesting file types.
 /// As a last resort we execute 'file' (except if forbidden by config)
 
-static string mimetypefromdata(const string &fn, bool usfc)
+static string mimetypefromdata(RclConfig *cfg, const string &fn, bool usfc)
 {
     // First try the internal identifying routine
     string mime = idFile(fn.c_str());
 
 #ifdef USE_SYSTEM_FILE_COMMAND
     if (usfc && mime.empty()) {
-	// Last resort: use "file -i"
+	// Last resort: use "file -i", or its configured replacement.
 	vector<string> cmd = create_vector<string>(FILE_PROG) ("-i") (fn);
+        string scommand;
+        if (cfg->getConfParam("systemfilecommand", scommand)) {
+            stringToStrings(scommand, cmd);
+            cmd.push_back(fn);
+        }
+
 	string result;
 	if (!ExecCmd::backtick(cmd, result)) {
 	    LOGERR(("mimetypefromdata: exec %s failed\n", FILE_PROG));
@@ -127,6 +133,9 @@ string mimetype(const string &fn, const struct stat *stp,
 	    return "inode/symlink";
 	if (!S_ISREG(stp->st_mode))
 	    return "inode/x-fsspecial";
+	// Empty files are just this: avoid further errors with actual filters.
+	if (stp->st_size == 0) 
+	    return "inode/x-empty";
     }
 
     string mtype;
@@ -153,18 +162,20 @@ string mimetype(const string &fn, const struct stat *stp,
     }
 
     // Compute file name suffix and search the mimetype map
-    string::size_type dot = fn.find_last_of(".");
-    string suff;
-    if (dot != string::npos) {
-        suff = stringtolower(fn.substr(dot));
+    string::size_type dot = fn.find_first_of(".");
+    while (dot != string::npos) {
+	string suff = stringtolower(fn.substr(dot));
 	mtype = cfg->getMimeTypeFromSuffix(suff);
+	if (!mtype.empty() || dot >= fn.size() - 1)
+	    break;
+	dot = fn.find_first_of(".", dot + 1);
     }
 
     // If type was not determined from suffix, examine file data. Can
     // only do this if we have an actual file (as opposed to a pure
     // name).
     if (mtype.empty() && stp)
-	mtype = mimetypefromdata(fn, usfc);
+	mtype = mimetypefromdata(cfg, fn, usfc);
 
  out:
     return mtype;
