@@ -17,6 +17,7 @@
 
 #ifndef TEST_SUBTREELIST
 
+#include "cstr.h"
 #include "refcntr.h"
 #include "rcldb.h"
 #include "searchdata.h"
@@ -25,7 +26,7 @@
 #include "debuglog.h"
 
 bool subtreelist(RclConfig *config, const string& top, 
-			list<string>& paths)
+		 vector<string>& paths)
 {
     LOGDEB(("subtreelist: top: [%s]\n", top.c_str()));
     Rcl::Db rcldb(config);
@@ -35,10 +36,10 @@ bool subtreelist(RclConfig *config, const string& top,
 	return false;
     }
 
-    Rcl::SearchData *sd = new Rcl::SearchData(Rcl::SCLT_OR);
+    Rcl::SearchData *sd = new Rcl::SearchData(Rcl::SCLT_OR, cstr_null);
     RefCntr<Rcl::SearchData> rq(sd);
 
-    rq->setTopdir(top);
+    sd->addClause(new Rcl::SearchDataClausePath(top, false));
 
     Rcl::Query query(&rcldb);
     query.setQuery(rq);
@@ -65,7 +66,7 @@ bool subtreelist(RclConfig *config, const string& top,
 #include <string.h>
 
 #include <iostream>
-#include <list>
+#include <vector>
 #include <string>
 using namespace std;
 
@@ -115,12 +116,12 @@ int main(int argc, char **argv)
 	exit(1);
     }
 
-    list<string> paths;
+    vector<string> paths;
     if (!subtreelist(config, top, paths)) {
 	cerr << "subtreelist failed" << endl;
 	exit(1);
     }
-    for (list<string>::const_iterator it = paths.begin(); 
+    for (vector<string>::const_iterator it = paths.begin(); 
 	 it != paths.end(); it++) {
 	cout << *it << endl;
     }
