@@ -30,11 +30,15 @@ using std::string;
  */
 class MimeHandlerText : public RecollFilter {
  public:
-    MimeHandlerText(RclConfig *cnf, const string& mt) 
-        : RecollFilter(cnf, mt), m_paging(false), m_offs(0) {}
-    virtual ~MimeHandlerText() {}
-    virtual bool set_document_file(const string &file_path);
-    virtual bool set_document_string(const string&);
+    MimeHandlerText(RclConfig *cnf, const string& id) 
+        : RecollFilter(cnf, id), m_paging(false), m_offs(0) 
+    {
+    }
+    virtual ~MimeHandlerText() 
+    {
+    }
+    virtual bool set_document_file(const string& mt, const string &file_path);
+    virtual bool set_document_string(const string&, const string&);
     virtual bool is_data_input_ok(DataInput input) const {
 	if (input == DOCUMENT_FILE_NAME || input == DOCUMENT_STRING)
 	    return true;
@@ -56,7 +60,8 @@ private:
     string m_fn;
     off_t  m_offs; // Offset of next read in file if we're paging
     size_t m_pagesz;
-    
+    string m_charsetfromxattr; 
+
     bool readnext();
 };
 
