@@ -38,7 +38,6 @@ using namespace std;
 #include "pathut.h"
 #include "searchdata.h"
 #include "rclquery.h"
-#include "wasastringtoquery.h"
 #include "wasatorcl.h"
 #include "kio_recoll.h"
 #include "docseqdb.h"
@@ -88,6 +87,12 @@ RecollProtocol::RecollProtocol(const QByteArray &pool, const QByteArray &app)
 	o_rclconfig->getConfParam("kio_always_dir", &m_alwaysdir);
     }
 
+    cp = getenv("RECOLL_KIO_STEMLANG");
+    if (cp) {
+        m_stemlang = cp;
+    } else {
+        m_stemlang = "english";
+    }
     m_pager.setParent(this);
     m_initok = true;
     return;
@@ -312,22 +317,14 @@ bool RecollProtocol::doSearch(const QueryDesc& qd)
 	if (opt == 'f') {
 	    clp = new Rcl::SearchDataClauseFilename(qs);
 	} else {
-	    // If there is no white space inside the query, then the user
-	    // certainly means it as a phrase.
-	    bool isreallyaphrase = false;
-	    if (!TextSplit::hasVisibleWhite(qs))
-		isreallyaphrase = true;
-	    clp = isreallyaphrase ? 
-		new Rcl::SearchDataClauseDist(Rcl::SCLT_PHRASE, qs, 0) :
-		new Rcl::SearchDataClauseSimple(opt == 'o' ?
-						Rcl::SCLT_OR : Rcl::SCLT_AND, 
-						qs);
+            clp = new Rcl::SearchDataClauseSimple(opt == 'o' ? Rcl::SCLT_OR : 
+                                                  Rcl::SCLT_AND, qs);
 	}
-	sd = new Rcl::SearchData(Rcl::SCLT_OR, "english");
+	sd = new Rcl::SearchData(Rcl::SCLT_OR, m_stemlang);
 	if (sd && clp)
 	    sd->addClause(clp);
     } else {
-	sd = wasaStringToRcl(o_rclconfig, "english", qs, m_reason);
+	sd = wasaStringToRcl(o_rclconfig, m_stemlang, qs, m_reason);
     }
     if (!sd) {
 	m_reason = "Internal Error: cant build search";
