@@ -174,7 +174,7 @@ ConfParamCStrW::ConfParamCStrW(QWidget *parent, ConfLink cflink,
     if (!createCommon(lbltxt, tltptxt))
 	return;
     m_cmb = new QComboBox(this);
-    m_cmb->setEditable(FALSE);
+    m_cmb->setEditable(false);
     m_cmb->insertItems(0, sl);
 
     setSzPol(m_cmb, QSizePolicy::Preferred, QSizePolicy::Fixed, 1, 0);
@@ -251,8 +251,12 @@ ConfParamFNW::ConfParamFNW(QWidget *parent, ConfLink cflink,
     m_hl->addWidget(m_le);
 
     m_pb = new QPushButton(this);
-    m_pb->setText(tr("Choose"));
-    setSzPol(m_pb, QSizePolicy::Fixed, QSizePolicy::Fixed, 1, 0);
+    
+    QString text = tr("Choose");
+    m_pb->setText(text);
+    int width = m_pb->fontMetrics().boundingRect(text).width() + 15;
+    m_pb->setMaximumWidth(width);
+    setSzPol(m_pb, QSizePolicy::Minimum, QSizePolicy::Fixed, 0, 0);
     m_hl->addWidget(m_pb);
 
     loadValue();
@@ -302,13 +306,19 @@ ConfParamSLW::ConfParamSLW(QWidget *parent, ConfLink cflink,
     vl1->addWidget(tl);
 
     QPushButton *pbA = new QPushButton(this);
-    pbA->setText(tr("+"));
-    setSzPol(pbA, QSizePolicy::Fixed, QSizePolicy::Fixed, 0, 0);
+    QString text = tr("+");
+    pbA->setText(text);
+    int width = pbA->fontMetrics().boundingRect(text).width() + 15;
+    pbA->setMaximumWidth(width);
+    setSzPol(pbA, QSizePolicy::Minimum, QSizePolicy::Fixed, 0, 0);
     hl1->addWidget(pbA);
 
     QPushButton *pbD = new QPushButton(this);
-    setSzPol(pbD, QSizePolicy::Fixed, QSizePolicy::Fixed, 0, 0);
-    pbD->setText(tr("-"));
+    text = tr("-");
+    pbD->setText(text);
+    width = pbD->fontMetrics().boundingRect(text).width() + 15;
+    pbD->setMaximumWidth(width);
+    setSzPol(pbD, QSizePolicy::Minimum, QSizePolicy::Fixed, 0, 0);
     hl1->addWidget(pbD);
 
     vl1->addLayout(hl1);
@@ -439,7 +449,7 @@ void ConfParamCSLW::showInputDialog()
 				       "", // label, 
 				       m_sl, // items, 
 				       0, // current = 0
-				       FALSE, // editable = true, 
+				       false, // editable = true, 
 				       &ok);
 
     if (ok && !s.isEmpty()) {
