@@ -331,6 +331,22 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>FragButs</name>
+    <message>
+        <source>%1 not found.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1:
+ %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Query Fragments</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>IdxSchedW</name>
     <message>
@@ -511,14 +527,6 @@ p, li { white-space: pre-wrap; }
         <source>These are patterns for file or directory  names which should not be indexed.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Default character set</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>This is the character set used for reading files which do not identify the character set internally, for example pure text files.&lt;br&gt;The default value is empty, and the value from the NLS environnement is used.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Follow symbolic links</source>
         <translation type="unfinished"></translation>
@@ -543,6 +551,98 @@ p, li { white-space: pre-wrap; }
         <source>Web history</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Default&lt;br&gt;character set</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Character set used for reading files which do not identify the character set internally, for example pure text files.&lt;br&gt;The default value is empty, and the value from the NLS environnement is used.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ignored endings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>These are file name endings for files which will be indexed by name only 
+(no MIME type identification attempt, no decompression, no content indexing).</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QWidget</name>
+    <message>
+        <source>Create or choose save directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Choose exactly one directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Could not read directory: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unexpected file name collision, cancelling.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cannot extract document: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Preview</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Open</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open With</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Run Script</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy &amp;File Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy &amp;URL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Write to File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save selection to files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Preview P&amp;arent document/folder</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Open Parent document/folder</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Find &amp;similar documents</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open &amp;Snippets window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show subdocuments / attachments</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RTIToolW</name>
@@ -730,10 +830,6 @@ p, li { white-space: pre-wrap; }
         <source>Missing helper programs</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Document category filter</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>No external viewer configured for mime type [</source>
         <translation type="unfinished"></translation>
@@ -848,22 +944,51 @@ Please check the mimeview file</source>
         <source>External applications/commands needed for your file types and not found, as stored by the last indexing pass in </source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Index not up to date for this file. Refusing to risk showing the wrong entry.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Click Ok to update the index for this file, then re-run the query when indexing is done. Else, Cancel.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Indexer running so things should improve when it&apos;s done</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Sub-documents and attachments</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Document filter</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Index not up to date for this file. Refusing to risk showing the wrong entry. </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Click Ok to update the index for this file, then you will need to re-run the query when indexing is done. </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The indexer is running so things should improve when it&apos;s done. </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The document belongs to an external indexwhich I can&apos;t update. </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Click Cancel to return to the list. Click Ignore to show the preview anyway. </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Duplicate documents</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>These Urls ( | ipath) share the same content:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bad desktop app spec for %1: [%2]
+Please check the desktop file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Indexing interrupted</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RclMainBase</name>
@@ -871,14 +996,6 @@ Please check the mimeview file</source>
         <source>Recoll</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Search tools</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Result list</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;File</source>
         <translation type="unfinished"></translation>
@@ -979,10 +1096,6 @@ Please check the mimeview file</source>
         <source>External index dialog</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>All</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Show missing helpers</source>
         <translation type="unfinished"></translation>
@@ -1091,6 +1204,29 @@ Please check the mimeview file</source>
         <source>First Page</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Query Fragments</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>    With failed files retrying</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Next update will retry previously failed files</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RclTrayIcon</name>
+    <message>
+        <source>Restore</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Quit</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RecollModel</name>
@@ -1221,14 +1357,6 @@ Please check the mimeview file</source>
         <source>&lt;p&gt;&lt;i&gt;Alternate spellings: &lt;/i&gt;</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Duplicate documents</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>These Urls ( | ipath) share the same content:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Result count (est.)</source>
         <translation type="unfinished"></translation>
@@ -1237,6 +1365,10 @@ Please check the mimeview file</source>
         <source>Query details</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Snippets</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ResTable</name>
@@ -1265,53 +1397,6 @@ Please check the mimeview file</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>ResultPopup</name>
-    <message>
-        <source>&amp;Preview</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Open</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Copy &amp;File Name</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Copy &amp;URL</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Write to File</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Save selection to files</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Preview P&amp;arent document/folder</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Open Parent document/folder</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Find &amp;similar documents</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Open &amp;Snippets window</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show subdocuments / attachments</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>SSearch</name>
     <message>
@@ -1338,22 +1423,6 @@ Please check the mimeview file</source>
         <source>Out of memory</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Enter query language expression. Cheat sheet:&lt;br&gt;
-&lt;i&gt;term1 term2&lt;/i&gt; : &apos;term1&apos; and &apos;term2&apos; in any field.&lt;br&gt;
-&lt;i&gt;field:term1&lt;/i&gt; : &apos;term1&apos; in field &apos;field&apos;.&lt;br&gt;
- Standard field names/synonyms:&lt;br&gt;
-  title/subject/caption, author/from, recipient/to, filename, ext.&lt;br&gt;
- Pseudo-fields: dir, mime/format, type/rclcat, date.&lt;br&gt;
- Two date interval exemples: 2009-03-01/2009-05-20  2009-03-01/P2M.&lt;br&gt;
-&lt;i&gt;term1 term2 OR term3&lt;/i&gt; : term1 AND (term2 OR term3).&lt;br&gt;
-  No actual parentheses allowed.&lt;br&gt;
-&lt;i&gt;&quot;term1 term2&quot;&lt;/i&gt; : phrase (must occur exactly). Possible modifiers:&lt;br&gt;
-&lt;i&gt;&quot;term1 term2&quot;p&lt;/i&gt; : unordered proximity search with default distance.&lt;br&gt;
-Use &lt;b&gt;Show Query&lt;/b&gt; link when in doubt about result and see manual (&amp;lt;F1&gt;) for more detail.
-</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Enter file name wildcard expression.</source>
         <translation type="unfinished"></translation>
@@ -1362,6 +1431,22 @@ Use &lt;b&gt;Show Query&lt;/b&gt; link when in doubt about result and see manual
         <source>Enter search terms here. Type ESC SPC for completions of current term.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Enter query language expression. Cheat sheet:&lt;br&gt;
+&lt;i&gt;term1 term2&lt;/i&gt; : &apos;term1&apos; and &apos;term2&apos; in any field.&lt;br&gt;
+&lt;i&gt;field:term1&lt;/i&gt; : &apos;term1&apos; in field &apos;field&apos;.&lt;br&gt;
+ Standard field names/synonyms:&lt;br&gt;
+  title/subject/caption, author/from, recipient/to, filename, ext.&lt;br&gt;
+ Pseudo-fields: dir, mime/format, type/rclcat, date, size.&lt;br&gt;
+ Two date interval exemples: 2009-03-01/2009-05-20  2009-03-01/P2M.&lt;br&gt;
+&lt;i&gt;term1 term2 OR term3&lt;/i&gt; : term1 AND (term2 OR term3).&lt;br&gt;
+  You can use parentheses to make things clearer.&lt;br&gt;
+&lt;i&gt;&quot;term1 term2&quot;&lt;/i&gt; : phrase (must occur exactly). Possible modifiers:&lt;br&gt;
+&lt;i&gt;&quot;term1 term2&quot;p&lt;/i&gt; : unordered proximity search with default distance.&lt;br&gt;
+Use &lt;b&gt;Show Query&lt;/b&gt; link when in doubt about result and see manual (&amp;lt;F1&gt;) for more detail.
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SSearchBase</name>
@@ -1462,6 +1547,10 @@ Use &lt;b&gt;Show Query&lt;/b&gt; link when in doubt about result and see manual
         <source>Search</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&lt;p&gt;Sorry, no exact match was found within limits. Probably the document is very big and the snippets generator got lost in a maze...&lt;/p&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SpellBase</name>
@@ -1643,6 +1732,10 @@ Use &lt;b&gt;Show Query&lt;/b&gt; link when in doubt about result and see manual
         <source>Cant add index with different case/diacritics stripping option</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Default QtWebkit font</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ViewAction</name>
@@ -1842,6 +1935,22 @@ This will help searching very big text  files (ie: log files).</source>
 </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Only mime types</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>An exclusive list of indexed mime types.&lt;br&gt;Nothing else will be indexed. Normally empty and inactive</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Exclude mime types</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mime types not to be indexed</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>confgui::ConfTopPanelW</name>
@@ -1992,10 +2101,6 @@ This will help searching very big text  files (ie: log files).</source>
         <source>Choose editor applications</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Display category filter as toolbar instead of button panel (needs restart).</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Auto-start simple search on whitespace entry.</source>
         <translation type="unfinished"></translation>
@@ -2205,5 +2310,33 @@ The default value is 2 (percent). </source>
         <source>Resets the Snippets window style</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Decide if document filters are shown as radio buttons, toolbar combobox, or menu.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Document filter choice style:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Buttons Panel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Toolbar Combobox</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show system tray icon.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Close to tray instead of exiting.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
