@@ -235,8 +235,11 @@ Usage(void)
 
 int main(int argc, char **argv)
 {
-    // If "-t" is present at all, we don't do the GUI thing and pass the 
-    // whole to recollq for command line / pipe usage.
+    // if we are named recollq or option "-t" is present at all, we
+    // don't do the GUI thing and pass the whole to recollq for
+    // command line / pipe usage.
+    if (!strcmp(argv[0], "recollq"))
+	    exit(recollq(&theconfig, argc, argv));
     for (int i = 0; i < argc; i++) {
 	if (!strcmp(argv[i], "-t")) {
 	    exit(recollq(&theconfig, argc, argv));
