@@ -279,6 +279,9 @@ void RclMain::init()
     QKeySequence seq("Ctrl+Shift+s");
     QShortcut *sc = new QShortcut(seq, this);
     connect(sc, SIGNAL (activated()), sSearch, SLOT (takeFocus()));
+    QKeySequence seql("Ctrl+l");
+    sc = new QShortcut(seql, this);
+    connect(sc, SIGNAL (activated()), sSearch, SLOT (takeFocus()));
 
     connect(&m_watcher, SIGNAL(fileChanged(QString)), 
 	    this, SLOT(idxStatus()));
@@ -322,6 +325,8 @@ void RclMain::init()
 	    this, SLOT(showSpellDialog()));
     connect(actionQuery_Fragments, SIGNAL(triggered()), 
 	    this, SLOT(showFragButs()));
+    connect(actionSpecial_Indexing, SIGNAL(triggered()), 
+	    this, SLOT(showSpecIdx()));
     connect(indexConfigAction, SIGNAL(triggered()), 
 	    this, SLOT(showIndexConfig()));
     connect(indexScheduleAction, SIGNAL(triggered()), 
@@ -619,7 +624,10 @@ void RclMain::fileExit()
     prefs.resArea = toolBarArea(m_resTB);
     restable->saveColState();
 
-    prefs.ssearchTyp = sSearch->searchTypCMB->currentIndex();
+    if (prefs.ssearchTypSav) {
+	prefs.ssearchTyp = sSearch->searchTypCMB->currentIndex();
+    }
+
     if (asearchform)
 	delete asearchform;
 
