@@ -16,6 +16,7 @@
  */
 #ifndef _RECOLL_H_INCLUDED_
 #define _RECOLL_H_INCLUDED_
+
 #include <string>
 
 #include "rclconfig.h"
@@ -31,12 +32,10 @@ extern bool maybeOpenDb(std::string &reason, bool force = true,
 			bool *maindberror = 0);
 
 /** Retrieve configured stemming languages */
-bool getStemLangs(list<string>& langs);
+bool getStemLangs(vector<string>& langs);
 
 extern RclConfig *theconfig;
-extern RclConfig *thestableconfig;
-extern PTMutexInit thestableconfiglock;
-extern void snapshotConfig();
+
 extern void rememberTempFile(TempFile);
 extern void forgetTempFile(string &fn);
 
@@ -51,4 +50,8 @@ class Aspell;
 extern Aspell *aspell;
 #endif
 
+inline std::string qs2utf8s(const QString& qs)
+{
+    return std::string((const char *)qs.toUtf8());
+}
 #endif /* _RECOLL_H_INCLUDED_ */
