@@ -35,7 +35,7 @@
 #include <QTextBlock>
 #include <QShortcut>
 #ifndef __APPLE__
-#include <qx11info_x11.h>
+//#include <qx11info_x11.h>
 #endif
 
 #include "debuglog.h"
@@ -58,6 +58,7 @@
 #ifdef RCL_USE_ASPELL
 #include "rclaspell.h"
 #endif
+#include "appformime.h"
 #include "respopup.h"
 
 static const QKeySequence quitKeySeq("Ctrl+q");
@@ -69,6 +70,13 @@ static const QKeySequence closeKeySeq("Ctrl+w");
 #include <QWebSettings>
 #endif
 
+// Decide if we set font family and style with a css section in the
+// html <head> or with qwebsettings setfont... calls.  We currently do
+// it with websettings because this gives an instant redisplay, and
+// the css has a tendancy to not find some system fonts. Otoh,
+// SetFontSize() needs a strange offset of 3, not needed with css.
+#undef SETFONT_WITH_HEADSTYLE
+
 class QtGuiResListPager : public ResListPager {
 public:
     QtGuiResListPager(ResList *p, int ps) 
@@ -174,7 +182,20 @@ string QtGuiResListPager::prevUrl()
 
 string QtGuiResListPager::headerContent() 
 {
-    return (const char *)prefs.reslistheadertext.toUtf8();
+    string out;
+
+    out = "<style type=\"text/css\">\nbody,table,select,input {\n";
+#ifdef SETFONT_WITH_HEADSTYLE
+    char ftsz[30];
+    sprintf(ftsz, "%d", prefs.reslistfontsize);
+    out += string("font-family: \"") + qs2utf8s(prefs.reslistfontfamily)
+        + "\";\n";
+    out += string("font-size: ") + ftsz + "pt;\n";
+#endif
+    out += string("color: ") + qs2utf8s(prefs.fontcolor) + ";\n";
+    out += string("}\n</style>\n");
+    out += qs2utf8s(prefs.reslistheadertext);
+    return out;
 }
 
 void QtGuiResListPager::suggest(const vector<string>uterms, 
@@ -269,7 +290,7 @@ public:
 	}
 		
 	return string("<span class='rclmatch' style='color: ")
-	    + string((const char *)prefs.qtermcolor.toAscii()) + string("'>");
+	    + qs2utf8s(prefs.qtermcolor) + string("'>");
     }
     virtual string endMatch() 
     {
@@ -310,8 +331,7 @@ ResList::ResList(QWidget* parent, const char* name)
     languageChange();
 
     (void)new HelpClient(this);
-    HelpClient::installMap((const char *)this->objectName().toAscii(), 
-			   "RCL.SEARCH.RESLIST");
+    HelpClient::installMap(qs2utf8s(this->objectName()), "RCL.SEARCH.RESLIST");
 
 #if 0
     // See comments in "highlighted
@@ -343,6 +363,7 @@ ResList::~ResList()
 	QT_TR_NOOP("Unavailable document"),
 	QT_TR_NOOP("Preview"),
 	QT_TR_NOOP("Open"),
+	QT_TR_NOOP("Snippets"),
 	QT_TR_NOOP("(show query)"),
         QT_TR_NOOP("<p><i>Alternate spellings (accents suppressed): </i>"),
         QT_TR_NOOP("<p><i>Alternate spellings: </i>"),
@@ -377,10 +398,13 @@ void ResList::setFont()
 	QTextBrowser::setFont(QFont());
     }
 #else
+#ifndef SETFONT_WITH_HEADSTYLE
     QWebSettings *websettings = settings();
     if (prefs.reslistfontfamily.length()) {
+        // For some reason there is (12-2014) an offset of 3 between what
+        // we request from webkit and what we get.
 	websettings->setFontSize(QWebSettings::DefaultFontSize, 
-				 prefs.reslistfontsize);
+				 prefs.reslistfontsize + 3);
 	websettings->setFontFamily(QWebSettings::StandardFont, 
 			       prefs.reslistfontfamily);
     } else {
@@ -388,6 +412,7 @@ void ResList::setFont()
 	websettings->resetFontFamily(QWebSettings::StandardFont);
     }
 #endif
+#endif
 }
 
 int ResList::newListId()
@@ -442,7 +467,7 @@ void ResList::resetView()
     QTextBrowser::append(".");
     clear();
 #ifndef __APPLE__
-    XFlush(QX11Info::display());
+//    XFlush(QX11Info::display());
 #endif
 #else
     m_text = "";
@@ -763,7 +788,7 @@ void ResList::previewExposed(int docnum)
 	QString sel = 
 	   QString("div[rcldocnum=\"%1\"]").arg(m_curPvDoc - pageFirstDocNum());
 	LOGDEB2(("Searching for element, selector: [%s]\n", 
-		 (const char *)sel.toAscii()));
+			 qs2utf8s(sel).c_str()));
 	QWebElement elt = page()->mainFrame()->findFirstElement(sel);
 	if (!elt.isNull()) {
 	    LOGDEB2(("Found\n"));
@@ -800,7 +825,7 @@ void ResList::previewExposed(int docnum)
     QString sel = 
 	QString("div[rcldocnum=\"%1\"]").arg(docnum - pageFirstDocNum());
     LOGDEB2(("Searching for element, selector: [%s]\n", 
-	    (const char *)sel.toAscii()));
+			 qs2utf8s(sel).c_str()));
     QWebElement elt = page()->mainFrame()->findFirstElement(sel);
     if (!elt.isNull()) {
 	LOGDEB2(("Found\n"));
@@ -837,7 +862,7 @@ void ResList::showQueryDetails()
 
 void ResList::linkWasClicked(const QUrl &url)
 {
-    string ascurl = (const char *)url.toString().toAscii();;
+    string ascurl = qs2utf8s(url.toString());
     LOGDEB(("ResList::linkWasClicked: [%s]\n", ascurl.c_str()));
 
     int what = ascurl[0];
@@ -876,6 +901,20 @@ void ResList::linkWasClicked(const QUrl &url)
     }
     break;
 
+    // Open parent folder
+    case 'F':
+    {
+	int i = atoi(ascurl.c_str()+1) - 1;
+	Rcl::Doc doc;
+	if (!getDoc(i, doc)) {
+	    LOGERR(("ResList::linkWasClicked: can't get doc for %d\n", i));
+	    return;
+	}
+        emit editRequested(ResultPopup::getParent(RefCntr<DocSequence>(),
+                                                  doc));
+    }
+    break;
+
     // Show query details
     case 'H': 
     {
@@ -913,6 +952,27 @@ void ResList::linkWasClicked(const QUrl &url)
 	resultPageBack();
 	break;
 
+	// Run script. Link format Rnn|Script Name
+    case 'R':
+    {
+	int i = atoi(ascurl.c_str() + 1) - 1;
+	QString s = url.toString();
+	int bar = s.indexOf("|");
+	if (bar == -1 || bar >= s.size()-1)
+            break;
+        string cmdname = qs2utf8s(s.right(s.size() - (bar + 1)));
+        DesktopDb ddb(path_cat(theconfig->getConfDir(), "scripts"));
+        DesktopDb::AppDef app;
+        if (ddb.appByName(cmdname, app)) {
+            QAction act(QString::fromUtf8(app.name.c_str()), this);
+            QVariant v(QString::fromUtf8(app.command.c_str()));
+            act.setData(v);
+            m_popDoc = i;
+            menuOpenWith(&act);
+        }
+    }
+    break;
+
 	// Spelling: replacement suggestion clicked
     case 'S':
     {
@@ -1027,6 +1087,15 @@ void ResList::menuEdit()
     if (getDoc(m_popDoc, doc))
 	emit editRequested(doc);
 }
+void ResList::menuOpenWith(QAction *act)
+{
+    if (act == 0)
+        return;
+    string cmd = qs2utf8s(act->data().toString());
+    Rcl::Doc doc;
+    if (getDoc(m_popDoc, doc))
+	emit openWithRequested(doc, cmd);
+}
 
 void ResList::menuCopyFN()
 {
