@@ -132,10 +132,13 @@ public slots:
     virtual void readDocSource(bool resetPos = true);
     virtual void onSortDataChanged(DocSeqSortSpec);
     virtual void createPopupMenu(const QPoint& pos);
+    virtual void onDoubleClick(const QModelIndex&);
     virtual void menuPreview();
     virtual void menuSaveToFile();
     virtual void menuSaveSelection();
     virtual void menuEdit();
+    virtual void menuEditAndQuit();
+    virtual void menuOpenWith(QAction *);
     virtual void menuCopyFN();
     virtual void menuCopyURL();
     virtual void menuExpand();
@@ -150,12 +153,14 @@ public slots:
     virtual void saveAsCSV(); 
     virtual void linkWasClicked(const QUrl&);
     virtual void makeRowVisible(int row);
+    virtual void takeFocus();
 
 signals:
     void docPreviewClicked(int, Rcl::Doc, int);
     void docSaveToFileClicked(Rcl::Doc);
     void previewRequested(Rcl::Doc);
     void editRequested(Rcl::Doc);
+    void openWithRequested(Rcl::Doc, string cmd);
     void headerClicked();
     void docExpand(Rcl::Doc);
     void showSubDocs(Rcl::Doc);
