@@ -37,6 +37,8 @@ public:
     SearchClauseW(QWidget* parent = 0);
     ~SearchClauseW();
     Rcl::SearchDataClause *getClause();
+    void setFromClause(Rcl::SearchDataClauseSimple *cl);
+    void clear();
 
     QComboBox* sTpCMB;
     QComboBox* fldCMB;
