@@ -17,12 +17,14 @@
 #include <stdio.h>
 #include <math.h>
 #include <time.h>
+
 #include <cmath>
+#include <list>
+using std::list;
 
 #include "docseqhist.h"
 #include "rcldb.h"
 #include "fileudi.h"
-#include "internfile.h"
 #include "base64.h"
 #include "debuglog.h"
 #include "smallut.h"
@@ -44,27 +46,27 @@ bool RclDHistoryEntry::encode(string& value)
 // Current entry format is "U time b64udi"
 bool RclDHistoryEntry::decode(const string &value)
 {
-    list<string> vall;
+    vector<string> vall;
     stringToStrings(value, vall);
 
-    list<string>::const_iterator it = vall.begin();
+    vector<string>::const_iterator it = vall.begin();
     udi.erase();
     string fn, ipath;
     switch (vall.size()) {
     case 2:
         // Old fn+ipath, null ipath case 
-        unixtime = atol((*it++).c_str());
+        unixtime = atoll((*it++).c_str());
         base64_decode(*it++, fn);
         break;
     case 3:
         if (!it->compare("U")) {
             // New udi-based entry
             it++;
-            unixtime = atol((*it++).c_str());
+            unixtime = atoll((*it++).c_str());
             base64_decode(*it++, udi);
         } else {
             // Old fn + ipath. We happen to know how to build an udi
-            unixtime = atol((*it++).c_str());
+            unixtime = atoll((*it++).c_str());
             base64_decode(*it++, fn);
             base64_decode(*it, ipath);
         }
@@ -134,21 +136,25 @@ bool DocSequenceHistory::getDoc(int num, Rcl::Doc &doc, string *sh)
 	} else
 	    sh->erase();
     }
-    bool ret = m_db->getDoc(m_it->udi, doc);
-    if (!ret) {
+
+    // For now history does not store an index id. Use empty doc as ref.
+    Rcl::Doc idxdoc;
+    bool ret = m_db->getDoc(m_it->udi, idxdoc, doc);
+    if (!ret || doc.pc == -1) {
 	doc.url = "UNKNOWN";
         doc.ipath = "";
     }
+
+    // Ensure the snippets link won't be shown as it does not make
+    // sense (no query terms...)
+    doc.haspages = 0;
+
     return ret;
 }
 
-bool DocSequenceHistory::getEnclosing(Rcl::Doc& doc, Rcl::Doc& pdoc) 
+Rcl::Db *DocSequenceHistory::getDb()
 {
-    string udi;
-    if (!FileInterner::getEnclosing(doc.url, doc.ipath, pdoc.url, pdoc.ipath,
-                                    udi))
-        return false;
-    return m_db->getDoc(udi, pdoc);
+    return m_db;
 }
 
 int DocSequenceHistory::getResCnt()
