@@ -24,12 +24,10 @@
 #include <map>
 #include <algorithm>
 
-#ifndef NO_NAMESPACES
 using std::vector;
 using std::list;
 using std::pair;
 using std::set;
-#endif /* NO_NAMESPACES */
 
 #include "rcldb.h"
 #include "rclconfig.h"
@@ -51,56 +49,79 @@ static string vecStringToString(const vector<string>& t)
     return sterms;
 }
 
-// Text splitter callback used to take note of the position of query terms 
-// inside the result text. This is then used to insert highlight tags. 
+struct MatchEntry {
+    // Start/End byte offsets in the document text
+    pair<int, int> offs;
+    // Index of the search group this comes from: this is to relate a 
+    // match to the original user input.
+    unsigned int grpidx;
+    MatchEntry(int sta, int sto, unsigned int idx) 
+	: offs(sta, sto), grpidx(idx)
+    {
+    }
+};
+
+// Text splitter used to take note of the position of query terms
+// inside the result text. This is then used to insert highlight tags.
 class TextSplitPTR : public TextSplit {
  public:
 
     // Out: begin and end byte positions of query terms/groups in text
-    vector<pair<int, int> > tboffs;  
+    vector<MatchEntry> tboffs;  
 
-    TextSplitPTR(const vector<string>& its, 
-                 const vector<vector<string> >&groups, 
-                 const vector<int>& slacks) 
-	:  m_wcount(0), m_groups(groups), m_slacks(slacks)
+    TextSplitPTR(const HighlightData& hdata)
+    :  m_wcount(0), m_hdata(hdata)
     {
-	for (vector<string>::const_iterator it = its.begin(); 
-	     it != its.end(); it++) {
-	    m_terms.insert(*it);
-	}
-	for (vector<vector<string> >::const_iterator vit = m_groups.begin(); 
-	     vit != m_groups.end(); vit++) {
-	    for (vector<string>::const_iterator it = (*vit).begin(); 
-		 it != (*vit).end(); it++) {
-		m_gterms.insert(*it);
+	// We separate single terms and groups and extract the group
+	// terms for computing positions list before looking for group
+	// matches
+	for (vector<vector<string> >::const_iterator vit = hdata.groups.begin();
+	     vit != hdata.groups.end(); vit++) {
+	    if (vit->size() == 1) {
+		m_terms[vit->front()] = vit - hdata.groups.begin();
+	    } else if (vit->size() > 1) {
+		for (vector<string>::const_iterator it = vit->begin(); 
+		     it != vit->end(); it++) {
+		    m_gterms.insert(*it);
+		}
 	    }
 	}
     }
 
-    // Callback called by the text-to-words breaker for each word
+    // Accept word and its position. If word is search term, add
+    // highlight zone definition. If word is part of search group
+    // (phrase or near), update positions list.
     virtual bool takeword(const std::string& term, int pos, int bts, int bte) {
-	string dumb;
-	if (!unacmaybefold(term, dumb, "UTF-8", true)) {
-	    LOGINFO(("PlainToRich::splitter::takeword: unac failed for [%s]\n",
-                     term.c_str()));
-	    return true;
+	string dumb = term;
+	if (o_index_stripchars) {
+	    if (!unacmaybefold(term, dumb, "UTF-8", UNACOP_UNACFOLD)) {
+		LOGINFO(("PlainToRich::takeword: unac failed for [%s]\n",
+			 term.c_str()));
+		return true;
+	    }
 	}
+
 	//LOGDEB2(("Input dumbbed term: '%s' %d %d %d\n", dumb.c_str(), 
 	// pos, bts, bte));
 
 	// If this word is a search term, remember its byte-offset span. 
-	if (m_terms.find(dumb) != m_terms.end()) {
-	    tboffs.push_back(pair<int, int>(bts, bte));
+	map<string, unsigned int>::const_iterator it = m_terms.find(dumb);
+	if (it != m_terms.end()) {
+	    tboffs.push_back(MatchEntry(bts, bte, (*it).second));
 	}
 	
+	// If word is part of a search group, update its positions list
 	if (m_gterms.find(dumb) != m_gterms.end()) {
 	    // Term group (phrase/near) handling
 	    m_plists[dumb].push_back(pos);
 	    m_gpostobytes[pos] = pair<int,int>(bts, bte);
 	    //LOGDEB2(("Recorded bpos for %d: %d %d\n", pos, bts, bte));
 	}
+
+	// Check for cancellation request
 	if ((m_wcount++ & 0xfff) == 0)
 	    CancelCheck::instance().checkCancel();
+
 	return true;
     }
 
@@ -108,17 +129,18 @@ class TextSplitPTR : public TextSplit {
     virtual bool matchGroups();
 
 private:
-    virtual bool matchGroup(const vector<string>& terms, int dist);
+    virtual bool matchGroup(unsigned int idx);
 
+    // Word count. Used to call checkCancel from time to time.
     int m_wcount;
 
     // In: user query terms
-    set<string>    m_terms; 
+    map<string, unsigned int>    m_terms; 
 
-    // In: user query groups, for near/phrase searches.
-    const vector<vector<string> >& m_groups;
-    const vector<int>&             m_slacks;
-    set<string>                    m_gterms;
+    // m_gterms holds all the terms in m_groups, as a set for quick lookup
+    set<string>    m_gterms;
+
+    const HighlightData& m_hdata;
 
     // group/near terms word positions.
     map<string, vector<int> > m_plists;
@@ -139,26 +161,37 @@ class VecIntCmpShorter {
 #define SETMINMAX(POS, STA, STO)  {if ((POS) < (STA)) (STA) = (POS); \
 	if ((POS) > (STO)) (STO) = (POS);}
 
-// Recursively check that each term is inside the window (which is
-// readjusted as the successive terms are found). i is the index for
-// the next position list to use (initially 1)
+// Check that at least an entry from the first position list is inside
+// the window and recurse on next list. The window is readjusted as
+// the successive terms are found.
+//
+// @param window the search window width
+// @param plists the position list vector
+// @param i the position list to process (we then recurse with the next list)
+// @param min the current minimum pos for a found term
+// @param max the current maximum pos for a found term
+// @param sp, ep output: the found area
+// @param minpos bottom of search: this is the highest point of
+//    any previous match. We don't look below this as overlapping matches 
+//    make no sense for highlighting.
 static bool do_proximity_test(int window, vector<vector<int>* >& plists, 
 			      unsigned int i, int min, int max, 
-			      int *sp, int *ep)
+			      int *sp, int *ep, int minpos)
 {
-    int tmp = max + 1;
-    // take care to avoid underflow
-    if (window <= tmp) 
-	tmp -= window; 
-    else 
-	tmp = 0;
-    vector<int>::iterator it = plists[i]->begin();
+    LOGDEB1(("do_prox_test: win %d i %d min %d max %d minpos %d\n", 
+	     window, i, min, max, minpos));
+    int tmp = max + 1 - window;
+    if (tmp < minpos)
+	tmp = minpos;
 
     // Find 1st position bigger than window start
+    vector<int>::iterator it = plists[i]->begin();
     while (it != plists[i]->end() && *it < tmp)
 	it++;
 
-    // Try each position inside window in turn for match with other lists
+    // Look for position inside window. If not found, no match. If
+    // found: if this is the last list we're done, else recurse on
+    // next list after adjusting the window
     while (it != plists[i]->end()) {
 	int pos = *it;
 	if (pos > min + window - 1) 
@@ -167,12 +200,8 @@ static bool do_proximity_test(int window, vector<vector<int>* >& plists,
 	    SETMINMAX(pos, *sp, *ep);
 	    return true;
 	}
-	if (pos < min) {
-	    min = pos;
-	} else if (pos > max) {
-	    max = pos;
-	}
-	if (do_proximity_test(window, plists, i + 1, min, max, sp, ep)) {
+	SETMINMAX(pos, min, max);
+	if (do_proximity_test(window,plists, i + 1, min, max, sp, ep, minpos)) {
 	    SETMINMAX(pos, *sp, *ep);
 	    return true;
 	}
@@ -181,10 +210,13 @@ static bool do_proximity_test(int window, vector<vector<int>* >& plists,
     return false;
 }
 
-// Check if there is a NEAR match for the group of terms
-bool TextSplitPTR::matchGroup(const vector<string>& terms, int window)
+// Find NEAR matches for one group of terms, update highlight map
+bool TextSplitPTR::matchGroup(unsigned int grpidx)
 {
-    LOGDEB0(("TextSplitPTR::matchGroup:d %d: %s\n", window,
+    const vector<string>& terms = m_hdata.groups[grpidx];
+    int window = m_hdata.groups[grpidx].size() + m_hdata.slacks[grpidx];
+
+    LOGDEB1(("TextSplitPTR::matchGroup:d %d: %s\n", window,
 	    vecStringToString(terms).c_str()));
 
     // The position lists we are going to work with. We extract them from the 
@@ -193,28 +225,25 @@ bool TextSplitPTR::matchGroup(const vector<string>& terms, int window)
     // A revert plist->term map. This is so that we can find who is who after
     // sorting the plists by length.
     map<vector<int>*, string> plistToTerm;
-    // For traces
-    vector<string> realgroup;
 
-    // Find the position list for each term in the group. Not all
-    // necessarily exist (esp for NEAR where terms have been
-    // stem-expanded: we don't know which matched)
+    // Find the position list for each term in the group. It is
+    // possible that this particular group was not actually matched by
+    // the search, so that some terms are not found.
     for (vector<string>::const_iterator it = terms.begin(); 
 	 it != terms.end(); it++) {
 	map<string, vector<int> >::iterator pl = m_plists.find(*it);
 	if (pl == m_plists.end()) {
-	    LOGDEB0(("TextSplitPTR::matchGroup: [%s] not found in m_plists\n",
+	    LOGDEB1(("TextSplitPTR::matchGroup: [%s] not found in m_plists\n",
 		    (*it).c_str()));
-	    continue;
+	    return false;
 	}
 	plists.push_back(&(pl->second));
 	plistToTerm[&(pl->second)] = *it;
-	realgroup.push_back(*it);
     }
-    LOGDEB0(("TextSplitPTR::matchGroup:d %d:real group after expansion %s\n", 
-	     window, vecStringToString(realgroup).c_str()));
+    // I think this can't actually happen, was useful when we used to
+    // prune the groups, but doesn't hurt.
     if (plists.size() < 2) {
-	LOGDEB0(("TextSplitPTR::matchGroup: no actual groups found\n"));
+	LOGDEB1(("TextSplitPTR::matchGroup: no actual groups found\n"));
 	return false;
     }
     // Sort the positions lists so that the shorter is first
@@ -228,35 +257,41 @@ bool TextSplitPTR::matchGroup(const vector<string>& terms, int window)
 	    LOGERR(("matchGroup: term for first list not found !?!\n"));
 	    return false;
 	}
-	LOGDEB0(("matchGroup: walking the shortest plist. Term [%s], len %d\n",
+	LOGDEB1(("matchGroup: walking the shortest plist. Term [%s], len %d\n",
 		it->second.c_str(), plists[0]->size()));
     }
 
+    // Minpos is the highest end of a found match. While looking for
+    // further matches, we don't want the search to extend before
+    // this, because it does not make sense for highlight regions to
+    // overlap
+    int minpos = 0;
     // Walk the shortest plist and look for matches
     for (vector<int>::iterator it = plists[0]->begin(); 
 	 it != plists[0]->end(); it++) {
 	int pos = *it;
 	int sta = int(10E9), sto = 0;
-	LOGDEB0(("MatchGroup: Testing at pos %d\n", pos));
-	if (do_proximity_test(window, plists, 1, pos, pos, &sta, &sto)) {
-	    LOGDEB0(("TextSplitPTR::matchGroup: MATCH termpos [%d,%d]\n", 
+	LOGDEB2(("MatchGroup: Testing at pos %d\n", pos));
+	if (do_proximity_test(window,plists, 1, pos, pos, &sta, &sto, minpos)) {
+	    LOGDEB1(("TextSplitPTR::matchGroup: MATCH termpos [%d,%d]\n", 
 		     sta, sto)); 
 	    // Maybe extend the window by 1st term position, this was not
 	    // done by do_prox..
 	    SETMINMAX(pos, sta, sto);
+	    minpos = sto+1;
 	    // Translate the position window into a byte offset window
-	    int bs = 0;
 	    map<int, pair<int, int> >::iterator i1 =  m_gpostobytes.find(sta);
 	    map<int, pair<int, int> >::iterator i2 =  m_gpostobytes.find(sto);
 	    if (i1 != m_gpostobytes.end() && i2 != m_gpostobytes.end()) {
-		LOGDEB0(("TextSplitPTR::matchGroup: pushing bpos %d %d\n",
+		LOGDEB2(("TextSplitPTR::matchGroup: pushing bpos %d %d\n",
 			i1->second.first, i2->second.second));
-		tboffs.push_back(pair<int, int>(i1->second.first, 
-						i2->second.second));
-		bs = i1->second.first;
+		tboffs.push_back(MatchEntry(i1->second.first, 
+					    i2->second.second, grpidx));
 	    } else {
-		LOGDEB(("matchGroup: no bpos found for %d or %d\n", sta, sto));
+		LOGDEB0(("matchGroup: no bpos found for %d or %d\n", sta, sto));
 	    }
+	} else {
+	    LOGDEB1(("matchGroup: no group match found at this position\n"));
 	}
     }
 
@@ -266,24 +301,27 @@ bool TextSplitPTR::matchGroup(const vector<string>& terms, int window)
 /** Sort integer pairs by increasing first value and decreasing width */
 class PairIntCmpFirst {
 public:
-    bool operator()(pair<int,int> a, pair<int, int>b) {
-	if (a.first != b.first)
-	    return a.first < b.first;
-	return a.second > b.second;
+    bool operator()(const MatchEntry& a, const MatchEntry& b) {
+	if (a.offs.first != b.offs.first)
+	    return a.offs.first < b.offs.first;
+	return a.offs.second > b.offs.second;
     }
 };
 
-// Do the phrase match thing, then merge the highlight lists
+// Look for matches to PHRASE and NEAR term groups and finalize the
+// matched regions list (sort it by increasing start then decreasing
+// length)
+// Actually, we handle all groups as NEAR (ignore order).
 bool TextSplitPTR::matchGroups()
 {
-    vector<vector<string> >::const_iterator vit = m_groups.begin();
-    vector<int>::const_iterator sit = m_slacks.begin();
-    for (; vit != m_groups.end() && sit != m_slacks.end(); vit++, sit++) {
-	matchGroup(*vit, *sit + (*vit).size());
+    for (unsigned int i = 0; i < m_hdata.groups.size(); i++) {
+	if (m_hdata.groups[i].size() <= 1)
+	    continue;
+	matchGroup(i);
     }
 
-    // Sort by start and end offsets. The merging of overlapping entries
-    // will be handled during output.
+    // Sort regions by increasing start and decreasing width.  
+    // The output process will skip overlapping entries.
     std::sort(tboffs.begin(), tboffs.end(), PairIntCmpFirst());
     return true;
 }
@@ -291,52 +329,33 @@ bool TextSplitPTR::matchGroups()
 
 // Fix result text for display inside the gui text window.
 //
-// To compute the term character positions in the output text, we used
-// to emulate how qt's textedit counts chars (ignoring tags and
-// duplicate whitespace etc...). This was tricky business, dependant
-// on qtextedit internals, and we don't do it any more, so we finally
-// don't know the term par/car positions in the editor text.  
-// Instead, we now mark the search term positions with html anchors
+// We call overridden functions to output header data, beginnings and ends of
+// matches etc.
 //
-// We output the result in chunks, arranging not to cut in the middle of
-// a tag, which would confuse qtextedit.
+// If the input is text, we output the result in chunks, arranging not
+// to cut in the middle of a tag, which would confuse qtextedit. If
+// the input is html, the body is always a single output chunk.
 bool PlainToRich::plaintorich(const string& in, 
 			      list<string>& out, // Output chunk list
-			      const HiliteData& hdata,
+			      const HighlightData& hdata,
 			      int chunksize)
 {
     Chrono chron;
-    const vector<string>& terms(hdata.terms);
-    const vector<vector<string> >& groups(hdata.groups);
-    const vector<int>& slacks(hdata.gslks);
-
-    if (0 && DebugLog::getdbl()->getlevel() >= DEBDEB0) {
-	LOGDEB0(("plaintorich: terms: \n"));
-	string sterms = vecStringToString(terms);
-	LOGDEB0(("  %s\n", sterms.c_str()));
-	sterms = "\n";
-	LOGDEB0(("plaintorich: groups: \n"));
-	for (vector<vector<string> >::const_iterator vit = groups.begin(); 
-	     vit != groups.end(); vit++) {
-	    sterms += "GROUP: ";
-	    sterms += vecStringToString(*vit);
-	    sterms += "\n";
-	}
-	LOGDEB0(("  %s", sterms.c_str()));
-        LOGDEB2(("  TEXT:[%s]\n", in.c_str()));
-    }
+    bool ret = true;
+    LOGDEB1(("plaintorichich: in: [%s]\n", in.c_str()));
 
+    m_hdata = &hdata;
     // Compute the positions for the query terms.  We use the text
     // splitter to break the text into words, and compare the words to
     // the search terms,
-    TextSplitPTR splitter(terms, groups, slacks);
+    TextSplitPTR splitter(hdata);
     // Note: the splitter returns the term locations in byte, not
     // character, offsets.
     splitter.text_to_words(in);
     LOGDEB2(("plaintorich: split done %d mS\n", chron.millis()));
-
     // Compute the positions for NEAR and PHRASE groups.
     splitter.matchGroups();
+    LOGDEB2(("plaintorich: group match done %d mS\n", chron.millis()));
 
     out.clear();
     out.push_back("");
@@ -345,11 +364,19 @@ bool PlainToRich::plaintorich(const string& in,
     // Rich text output
     *olit = header();
 
+    // No term matches. Happens, for example on a snippet selected for
+    // a term match when we are actually looking for a group match
+    // (the snippet generator does this...).
+    if (splitter.tboffs.empty()) {
+	LOGDEB1(("plaintorich: no term matches\n"));
+	ret = false;
+    }
+
     // Iterator for the list of input term positions. We use it to
     // output highlight tags and to compute term positions in the
     // output text
-    vector<pair<int, int> >::iterator tPosIt = splitter.tboffs.begin();
-    vector<pair<int, int> >::iterator tPosEnd = splitter.tboffs.end();
+    vector<MatchEntry>::iterator tPosIt = splitter.tboffs.begin();
+    vector<MatchEntry>::iterator tPosEnd = splitter.tboffs.end();
 
 #if 0
     for (vector<pair<int, int> >::const_iterator it = splitter.tboffs.begin();
@@ -367,8 +394,6 @@ bool PlainToRich::plaintorich(const string& in,
     int hadcr = 0;
     int inindent = 1;
 
-    // Value for numbered anchors at each term match
-    int anchoridx = 1;
     // HTML state
     bool intag = false, inparamvalue = false;
     // My tag state
@@ -393,22 +418,20 @@ bool PlainToRich::plaintorich(const string& in,
 	// we are at or after a term match, mark.
 	if (tPosIt != tPosEnd) {
 	    int ibyteidx = chariter.getBpos();
-	    if (ibyteidx == tPosIt->first) {
-		if (!intag && ibyteidx > (int)headend) {
-		    *olit += startAnchor(anchoridx);
-		    *olit += startMatch();
+	    if (ibyteidx == tPosIt->offs.first) {
+		if (!intag && ibyteidx >= (int)headend) {
+		    *olit += startMatch(tPosIt->grpidx);
 		}
-		anchoridx++;
                 inrcltag = 1;
-	    } else if (ibyteidx == tPosIt->second) {
+	    } else if (ibyteidx == tPosIt->offs.second) {
 		// Output end of match region tags
 		if (!intag && ibyteidx > (int)headend) {
 		    *olit += endMatch();
-		    *olit += endAnchor();
 		}
 		// Skip all highlight areas that would overlap this one
-		int crend = tPosIt->second;
-		while (tPosIt != splitter.tboffs.end() && tPosIt->first < crend)
+		int crend = tPosIt->offs.second;
+		while (tPosIt != splitter.tboffs.end() && 
+		       tPosIt->offs.first < crend)
 		    tPosIt++;
                 inrcltag = 0;
 	    }
@@ -519,5 +542,5 @@ bool PlainToRich::plaintorich(const string& in,
     }
 #endif
     LOGDEB2(("plaintorich: done %d mS\n", chron.millis()));
-    return true;
+    return ret;
 }
