@@ -38,8 +38,8 @@ using std::list;
 #include "mimehandler.h"
 
 // Default highlighter. No need for locking, this is query-only.
-static const string cstr_hlfontcolor("<font color=\"blue\">");
-static const string cstr_hlendfont("</font>");
+static const string cstr_hlfontcolor("<span style='color: blue;'>");
+static const string cstr_hlendfont("</span>");
 class PlainToRichHtReslist : public PlainToRich {
 public:
     virtual string startMatch(unsigned int) 
@@ -167,6 +167,13 @@ void ResListPager::displayDoc(RclConfig *config, int i, Rcl::Doc& doc,
     string url;
     printableUrl(config->getDefCharset(), doc.url, url);
 
+    // Same as url, but with file:// possibly stripped. output by %u instead
+    // of %U. 
+    string urlOrLocal;
+    urlOrLocal = fileurltolocalpath(url);
+    if (urlOrLocal.empty())
+        urlOrLocal = url;
+
     // Make title out of file name if none yet
     string titleOrFilename;
     string utf8fn;
@@ -179,6 +186,15 @@ void ResListPager::displayDoc(RclConfig *config, int i, Rcl::Doc& doc,
 	titleOrFilename = utf8fn;
     }
 
+    // Url for the parent directory. We strip the file:// part for local
+    // paths
+    string parenturl = url_parentfolder(url);
+    {
+        string localpath = fileurltolocalpath(parenturl);
+        if (!localpath.empty())
+            parenturl = localpath;
+    }
+
     // Result number
     char numbuf[20];
     int docnumforlinks = m_winfirst + 1 + i;
@@ -286,11 +302,13 @@ void ResListPager::displayDoc(RclConfig *config, int i, Rcl::Doc& doc,
     subs["L"] = linksbuf.str();
     subs["N"] = numbuf;
     subs["M"] = doc.mimetype;
+    subs["P"] = parenturl;
     subs["R"] = doc.meta[Rcl::Doc::keyrr];
     subs["S"] = sizebuf;
     subs["T"] = maybeEscapeHtml(titleOrFilename);
     subs["t"] = maybeEscapeHtml(doc.meta[Rcl::Doc::keytt]);
     subs["U"] = url;
+    subs["u"] = urlOrLocal;
 
     // Let %(xx) access all metadata. HTML-neuter everything:
     for (map<string,string>::iterator it = doc.meta.begin(); 
@@ -351,9 +369,9 @@ void ResListPager::displayPage(RclConfig *config)
 	  << headerContent()
 	  << "</head><body>" << endl
 	  << pageTop()
-	  << "<p><font size=+1><b>"
+	  << "<p><span style=\"font-size:110%;\"><b>"
 	  << m_docSource->title()
-	  << "</b></font>&nbsp;&nbsp;&nbsp;";
+	  << "</b></span>&nbsp;&nbsp;&nbsp;";
 
     if (pageEmpty()) {
 	chunk << trans("<p><b>No results found</b><br>");
