@@ -19,14 +19,13 @@
 #define _reslistpager_h_included_
 
 #include <vector>
-using std::vector;
 
 #include "refcntr.h"
 #include "docseq.h"
+#include "hldata.h"
 
 class RclConfig;
 class PlainToRich;
-class HiliteData;
 
 /**
  * Manage a paged HTML result list. 
@@ -85,12 +84,14 @@ public:
     void resultPageFor(int docnum);
     void displayPage(RclConfig *);
     void displayDoc(RclConfig *, int idx, Rcl::Doc& doc, 
-		    const HiliteData& hdata, const string& sh = "");
+		    const HighlightData& hdata, const string& sh = "");
     bool pageEmpty() {return m_respage.size() == 0;}
 
     string queryDescription() {return m_docSource.isNull() ? "" :
 	    m_docSource->getDescription();}
 
+    bool getDoc(int num, Rcl::Doc &doc);
+
     // Things that need to be reimplemented in the subclass:
     virtual bool append(const string& data);
     virtual bool append(const string& data, int, const Rcl::Doc&)
@@ -112,8 +113,9 @@ public:
     virtual string pageTop() {return string();}
     virtual string headerContent() {return string();}
     virtual string iconUrl(RclConfig *, Rcl::Doc& doc);
-    virtual void suggest(const vector<string>, 
-			 map<string, vector<string> >& sugg) {
+    virtual void suggest(const std::vector<std::string>, 
+			std::map<std::string, std::vector<std::string> >& sugg) 
+    {
         sugg.clear();
     }
     virtual string absSep() {return "&hellip;";}
@@ -126,7 +128,7 @@ private:
     bool                 m_hasNext;
     PlainToRich         *m_hiliter;
     RefCntr<DocSequence> m_docSource;
-    vector<ResListEntry> m_respage;
+    std::vector<ResListEntry> m_respage;
 };
 
 #endif /* _reslistpager_h_included_ */
