@@ -14,6 +14,9 @@
  *   Free Software Foundation, Inc.,
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
+
+#include "autoconfig.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <signal.h>
@@ -36,7 +39,8 @@ using namespace std;
 static string thisprog;
 
 static string usage =
-    " -d <dbdir> -e <output encoding>\n"
+    " -d <dbdir> \n"
+    "-e <output encoding>\n"
     " -i docid -D : get document data for docid\n"
     " -i docid -X : delete document docid\n"
     " -i docid -b : 'rebuild' document from term positions\n"
@@ -112,6 +116,17 @@ static void sigcleanup(int sig)
     exit(1);
 }
 
+bool o_index_stripchars;
+
+inline bool has_prefix(const string& trm)
+{
+    if (o_index_stripchars) {
+	return trm.size() && 'A' <= trm[0] && trm[0] <= 'Z';
+    } else {
+	return trm.size() > 0 && trm[0] == ':';
+    }
+}
+
 int main(int argc, char **argv)
 {
     string dbdir = path_cat(path_home(), ".recoll/xapiandb");
@@ -188,10 +203,20 @@ int main(int argc, char **argv)
 
     try {
 	db = new Xapian::Database(dbdir);
-
 	cout << "DB: ndocs " << db->get_doccount() << " lastdocid " <<
 	    db->get_lastdocid() << " avglength " << db->get_avlength() << endl;
-	    
+
+	// If we have terms with a leading ':' it's a new style,
+	// unstripped index
+	{
+	    Xapian::TermIterator term = db->allterms_begin(":");
+	    if (term == db->allterms_end())
+		o_index_stripchars = true;
+	    else
+		o_index_stripchars = false;
+	    cout<<"DB: terms are "<<(o_index_stripchars?"stripped":"raw")<<endl;
+	}
+    
 	if (op_flags & OPT_T) {
 	    Xapian::TermIterator term;
 	    string printable;
@@ -201,8 +226,7 @@ int main(int argc, char **argv)
 		for (term = db->termlist_begin(docid); 
 		     term != db->termlist_end(docid);term++) {
 		    const string& s = *term;
-		    if ((op_flags&OPT_l) && 
-			!s.empty() && s[0] >= 'A' && s[0] <= 'Z')
+		    if ((op_flags&OPT_l) && has_prefix(s))
 			continue;
 		    cout << op << detailstring(s) << cl << endl;
 		}
@@ -210,8 +234,7 @@ int main(int argc, char **argv)
 		for (term = db->allterms_begin(); 
 		     term != db->allterms_end();term++) {
 		    const string& s = *term;
-		    if ((op_flags&OPT_l) && 
-			!s.empty() && s[0] >= 'A' && s[0] <= 'Z')
+		    if ((op_flags&OPT_l) && has_prefix(s))
 			continue;
 		    if (op_flags & OPT_f)
 			cout <<  db->get_collection_freq(*term) << " " 
