@@ -19,8 +19,7 @@
 #include <math.h>
 
 #include <map>
-#include <tr1/unordered_set>
-using std::tr1::unordered_set;
+#include "unordered_defs.h"
 
 using namespace std;
 
@@ -284,7 +283,7 @@ int Query::Native::getFirstMatchPage(Xapian::docid docid, string& term)
     multimap<double, vector<string> > byQ;
     double totalweight = qualityTerms(docid, terms, byQ);
 
-    for (map<double, vector<string> >::reverse_iterator mit = byQ.rbegin(); 
+    for (multimap<double, vector<string> >::reverse_iterator mit = byQ.rbegin(); 
 	 mit != byQ.rend(); mit++) {
 	for (vector<string>::const_iterator qit = mit->second.begin();
 	     qit != mit->second.end(); qit++) {
@@ -362,7 +361,7 @@ int Query::Native::makeAbstract(Xapian::docid docid,
     map<unsigned int, string> sparseDoc;
     // Also remember apart the search term positions so that we can list
     // them with their snippets.
-    unordered_set<unsigned int> searchTermPositions;
+    STD_UNORDERED_SET<unsigned int> searchTermPositions;
 
     // Remember max position. Used to stop walking positions lists while 
     // populating the adjacent slots.
@@ -385,7 +384,7 @@ int Query::Native::makeAbstract(Xapian::docid docid,
     int ret = ABSRES_OK;
 
     // Let's go populate
-    for (map<double, vector<string> >::reverse_iterator mit = byQ.rbegin(); 
+    for (multimap<double, vector<string> >::reverse_iterator mit = byQ.rbegin(); 
 	 mit != byQ.rend(); mit++) {
 	unsigned int maxgrpoccs;
 	float q;
