@@ -208,14 +208,35 @@ void SearchData::simplify()
         clsubp->getSub()->simplify();
 
         // If this subquery has special attributes, it's not a
-        // candidate for collapsing
+        // candidate for collapsing, except if it has no clauses, because
+        // then, we just pick the attributes.
         if (!clsubp->getSub()->m_filetypes.empty() || 
             !clsubp->getSub()->m_nfiletypes.empty() ||
             clsubp->getSub()->m_haveDates || 
             clsubp->getSub()->m_maxSize != size_t(-1) ||
             clsubp->getSub()->m_minSize != size_t(-1) ||
-            clsubp->getSub()->m_haveWildCards)
-            continue;
+            clsubp->getSub()->m_haveWildCards) {
+            if (!clsubp->getSub()->m_query.empty())
+                continue;
+            m_filetypes.insert(m_filetypes.end(),
+                               clsubp->getSub()->m_filetypes.begin(),
+                               clsubp->getSub()->m_filetypes.end());
+            m_nfiletypes.insert(m_nfiletypes.end(),
+                               clsubp->getSub()->m_nfiletypes.begin(),
+                               clsubp->getSub()->m_nfiletypes.end());
+            if (clsubp->getSub()->m_haveDates && !m_haveDates) {
+                m_dates = clsubp->getSub()->m_dates;
+            }
+            if (m_maxSize == size_t(-1))
+                m_maxSize = clsubp->getSub()->m_maxSize;
+            if (m_minSize == size_t(-1))
+                m_minSize = clsubp->getSub()->m_minSize;
+            m_haveWildCards = m_haveWildCards ||
+                clsubp->getSub()->m_haveWildCards;
+            // And then let the clauses processing go on, there are
+            // none anyway, we will just delete the subquery.
+        }
+        
 
         bool allsametp = true;
         for (qlist_it_t it1 = clsubp->getSub()->m_query.begin(); 
@@ -270,18 +291,36 @@ void SearchData::getTerms(HighlightData &hld) const
     return;
 }
 
+static const char * tpToString(SClType t)
+{
+    switch (t) {
+    case SCLT_AND: return "AND";
+    case SCLT_OR: return "OR";
+    case SCLT_FILENAME: return "FILENAME";
+    case SCLT_PHRASE: return "PHRASE";
+    case SCLT_NEAR: return "NEAR";
+    case SCLT_PATH: return "PATH";
+    case SCLT_SUB: return "SUB";
+    default: return "UNKNOWN";
+    }
+}
+
+static string dumptabs;
+
 void SearchData::dump(ostream& o) const
 {
-    o << "SearchData: " << " qs " << int(m_query.size()) << 
+    o << dumptabs <<
+        "SearchData: " << tpToString(m_tp) << " qs " << int(m_query.size()) << 
         " ft " << m_filetypes.size() << " nft " << m_nfiletypes.size() << 
         " hd " << m_haveDates << " maxs " << int(m_maxSize) << " mins " << 
         int(m_minSize) << " wc " << m_haveWildCards << "\n";
     for (std::vector<SearchDataClause*>::const_iterator it =
              m_query.begin(); it != m_query.end(); it++) {
+        o << dumptabs;
         (*it)->dump(o);
         o << "\n";
     }
-    o << "\n";
+//    o << dumptabs << "\n";
 }
 
 void SearchDataClause::dump(ostream& o) const
@@ -291,7 +330,7 @@ void SearchDataClause::dump(ostream& o) const
 
 void SearchDataClauseSimple::dump(ostream& o) const
 {
-    o << "ClauseSimple: ";
+    o << "ClauseSimple: " << tpToString(m_tp) << " ";
     if (m_exclude)
         o << "- ";
     o << "[" ;
@@ -319,9 +358,9 @@ void SearchDataClausePath::dump(ostream& o) const
 void SearchDataClauseDist::dump(ostream& o) const
 {
     if (m_tp == SCLT_NEAR)
-        o << "ClauseDist: NEAR: ";
+        o << "ClauseDist: NEAR ";
     else
-        o << "ClauseDist: PHRA: ";
+        o << "ClauseDist: PHRA ";
             
     if (m_exclude)
         o << " - ";
@@ -334,8 +373,10 @@ void SearchDataClauseDist::dump(ostream& o) const
 void SearchDataClauseSub::dump(ostream& o) const
 {
     o << "ClauseSub {\n";
+    dumptabs += '\t';
     m_sub.getconstptr()->dump(o);
-    o << "}";
+    dumptabs.erase(dumptabs.size()- 1);
+    o << dumptabs << "}";
 }
 
 } // Namespace Rcl
