@@ -19,10 +19,7 @@
 /* Macros for log and debug messages */
 #include <stack>
 
-#ifndef NO_NAMESPACES
 namespace DebugLog {
-    using std::stack;
-#endif // NO_NAMESPACES
 
 #ifndef DEBUGLOG_USE_THREADS
 #define DEBUGLOG_USE_THREADS 1
@@ -44,7 +41,7 @@ namespace DebugLog {
 class DebugLogWriter;
 
 class DebugLog {
-    stack<int> levels;
+    std::stack<int> levels;
     int debuglevel;
     int dodate;
     DebugLogWriter *writer;
@@ -69,6 +66,8 @@ class DebugLog {
 extern DebugLog *getdbl();
 extern const char *getfilename();
 extern int setfilename(const char *fname, int trnc = 1);
+extern int reopen();
+
 #if STATICVERBOSITY >= DEBFATAL
 #define LOGFATAL(X) {if (DebugLog::getdbl()->getlevel()>=DEBFATAL){DebugLog::getdbl()->prolog(DEBFATAL,__FILE__,__LINE__) ;DebugLog::getdbl()->log X;}}
 #else
@@ -109,7 +108,5 @@ extern int setfilename(const char *fname, int trnc = 1);
 #else
 #define LOGDEB3(X)
 #endif
-#ifndef NO_NAMESPACES
 }
-#endif // NO_NAMESPACES
 #endif /* _DEBUGLOG_H_ */
