@@ -60,6 +60,8 @@ extern bool printableUrl(const std::string &fcharset,
 extern std::string fileurltolocalpath(std::string url);
 /// Test for file:/// url
 extern bool urlisfileurl(const std::string& url);
+/// 
+extern std::string url_parentfolder(const std::string& url);
 
 /// Return the host+path part of an url. This is not a general
 /// routine, it does the right thing only in the recoll context
@@ -75,7 +77,7 @@ extern bool readdir(const std::string& dir, std::string& reason,
 /** A small wrapper around statfs et al, to return percentage of disk
     occupation */
 bool fsocc(const std::string &path, int *pc, // Percent occupied
-	   long *avmbs = 0 // Mbs available to non-superuser
+	   long long *avmbs = 0 // Mbs available to non-superuser. Mb=1024*1024
 	   );
 
 /// Retrieve the temp dir location: $RECOLL_TMPDIR else $TMPDIR else /tmp
