@@ -17,10 +17,14 @@
 #include <stdio.h>
 #include <unistd.h>
 
+#include <string>
+
 #include "rclionice.h"
 #include "execmd.h"
 #include "debuglog.h"
 
+using namespace std;
+
 bool rclionice(const string& clss, const string& cdata)
 {
     string ionicexe;
