@@ -24,12 +24,10 @@
 #include <map>
 #include <set>
 
-#ifndef NO_NAMESPACES
 using std::string;
 using std::vector;
 using std::map;
 using std::set;
-#endif /* NO_NAMESPACES */
 
 // Note these are all ascii routines
 extern int stringicmp(const string& s1, const string& s2);
@@ -143,9 +141,9 @@ string displayableBytes(off_t size);
 string breakIntoLines(const string& in, unsigned int ll = 100, 
 		      unsigned int maxlines= 50);
 /** Small utility to substitute printf-like percents cmds in a string */
-bool pcSubst(const string& in, string& out, map<char, string>& subs);
+bool pcSubst(const string& in, string& out, const map<char, string>& subs);
 /** Substitute printf-like percents and also %(key) */
-bool pcSubst(const string& in, string& out, map<string, string>& subs);
+bool pcSubst(const string& in, string& out, const map<string, string>& subs);
 
 /** Append system error message */
 void catstrerror(string *reason, const char *what, int _errno);
@@ -199,6 +197,11 @@ inline void leftzeropad(string& s, unsigned len)
 	s = s.insert(0, len - s.length(), '0');
 }
 
+// Duplicate map<string,string> while ensuring no shared string data (to pass
+// to other thread):
+void map_ss_cp_noshr(const std::map<std::string,std::string> s,
+                      std::map<std::string,std::string> *d);
+
 // Code for static initialization of an stl map. Somewhat like Boost.assign. 
 // Ref: http://stackoverflow.com/questions/138600/initializing-a-static-stdmapint-int-in-c
 // Example use: map<int, int> m = create_map<int, int> (1,2) (3,4) (5,6) (7,8);
