@@ -20,6 +20,7 @@
 #ifdef UTF8ITER_CHECK
 #include "assert.h"
 #endif
+#include <string>
 
 /** 
  * A small helper class to iterate over utf8 strings. This is not an
@@ -30,20 +31,19 @@
  */
 class Utf8Iter {
 public:
-    Utf8Iter(const string &in) 
-	: m_s(in), m_cl(0), m_pos(0), m_charpos(0), m_error(false)
+    Utf8Iter(const std::string &in) 
+	: m_s(in), m_cl(0), m_pos(0), m_charpos(0)
     {
 	update_cl();
     }
 
-    const string& buffer() const {return m_s;}
+    const std::string& buffer() const {return m_s;}
 
     void rewind() 
     {
 	m_cl = 0; 
 	m_pos = 0; 
 	m_charpos = 0; 
-	m_error = false;
 	update_cl();
     }
 
@@ -52,7 +52,7 @@ public:
      * current position */
     unsigned int operator[](unsigned int charpos) const 
     {
-	string::size_type mypos = 0;
+	std::string::size_type mypos = 0;
 	unsigned int mycp = 0;
 	if (charpos >= m_charpos) {
 	    mypos = m_pos;
@@ -61,29 +61,29 @@ public:
 	int l;
 	while (mypos < m_s.length() && mycp != charpos) {
 	    l = get_cl(mypos);
-	    if (l <= 0)
+	    if (l <= 0 || !poslok(mypos, l) || !checkvalidat(mypos, l))
 		return (unsigned int)-1;
 	    mypos += l;
 	    ++mycp;
 	}
 	if (mypos < m_s.length() && mycp == charpos) {
 	    l = get_cl(mypos);
-	    if (poslok(mypos, l))
-		return getvalueat(mypos, get_cl(mypos));
+	    if (poslok(mypos, l) && checkvalidat(mypos, l))
+		return getvalueat(mypos, l);
 	}
 	return (unsigned int)-1;
     }
 
     /** Increment current position to next utf-8 char */
-    string::size_type operator++(int) 
+    std::string::size_type operator++(int) 
     {
 	// Note: m_cl may be zero at eof if user's test not right
 	// this shouldn't crash the program until actual data access
 #ifdef UTF8ITER_CHECK
 	assert(m_cl != 0);
 #endif
-	if (m_cl <= 0) 
-	    return string::npos;
+	if (m_cl == 0)
+	    return std::string::npos;
 
 	m_pos += m_cl;
 	m_charpos++;
@@ -95,14 +95,14 @@ public:
     unsigned int operator*() 
     {
 #ifdef UTF8ITER_CHECK
-	assert(m_cl != 0);
+	assert(m_cl > 0);
 #endif
-	return getvalueat(m_pos, m_cl);
+	return m_cl == 0 ? (unsigned int)-1 : getvalueat(m_pos, m_cl);
     }
 
     /** Append current utf-8 possibly multi-byte character to string param.
 	This needs to be fast. No error checking. */
-    unsigned int appendchartostring(string &out) {
+    unsigned int appendchartostring(std::string &out) const {
 #ifdef UTF8ITER_CHECK
 	assert(m_cl != 0);
 #endif
@@ -111,58 +111,56 @@ public:
     }
 
     /** Return current character as string */
-    operator string() {
+    operator std::string() {
 #ifdef UTF8ITER_CHECK
 	assert(m_cl != 0);
 #endif
-	return m_s.substr(m_pos, m_cl);
+	return m_cl > 0 ? m_s.substr(m_pos, m_cl) : std::string();
     }
 
-    bool eof() {
+    bool eof() const {
 	return m_pos == m_s.length();
     }
 
-    bool error() {
-	return m_error;
+    bool error() const {
+	return m_cl == 0;
     }
 
     /** Return current byte offset in input string */
-    string::size_type getBpos() const {
+    std::string::size_type getBpos() const {
 	return m_pos;
     }
 
     /** Return current character length */
-    string::size_type getBlen() const {
+    std::string::size_type getBlen() const {
 	return m_cl;
     }
 
     /** Return current unicode character offset in input string */
-    string::size_type getCpos() const {
+    std::string::size_type getCpos() const {
 	return m_charpos;
     }
 
 private:
     // String we're working with
-    const string&     m_s; 
+    const std::string&     m_s; 
     // Character length at current position. A value of zero indicates
     // an error.
-    unsigned int      m_cl; 
+    unsigned int m_cl;
     // Current byte offset in string.
-    string::size_type m_pos; 
+    std::string::size_type m_pos; 
     // Current character position
     unsigned int      m_charpos; 
-    // Am I ok ?
-    mutable bool      m_error;
 
     // Check position and cl against string length
-    bool poslok(string::size_type p, int l) const {
+    bool poslok(std::string::size_type p, int l) const {
 #ifdef UTF8ITER_CHECK
-	assert(p != string::npos && l > 0 && p + l <= m_s.length());
+	assert(p != std::string::npos && l > 0 && p + l <= m_s.length());
 #endif
-	return p != string::npos && l > 0 && p + l <= m_s.length();
+	return p != std::string::npos && l > 0 && p + l <= m_s.length();
     }
 
-    // Update current char length in object state, minimum checking
+    // Update current char length in object state, check
     // for errors
     inline void update_cl() 
     {
@@ -175,12 +173,39 @@ private:
 	    // basically prevents the caller to discriminate error and eof.
 	    //	    m_pos = m_s.length();
 	    m_cl = 0;
-	    m_error = true;
+	    return;
+	}
+	if (!checkvalidat(m_pos, m_cl)) {
+	    m_cl = 0;
+	}
+    }
+
+    inline bool checkvalidat(std::string::size_type p, int l) const
+    {
+	switch (l) {
+	case 1: 
+	    return (unsigned char)m_s[p] < 128;
+	case 2: 
+	    return (((unsigned char)m_s[p]) & 224) == 192
+		&& (((unsigned char)m_s[p+1]) & 192) == 128;
+	case 3: 
+	    return (((unsigned char)m_s[p]) & 240) == 224
+		   && (((unsigned char)m_s[p+1]) & 192) ==  128
+		   && (((unsigned char)m_s[p+2]) & 192) ==  128
+		   ;
+	case 4: 
+	    return (((unsigned char)m_s[p]) & 248) == 240
+		   && (((unsigned char)m_s[p+1]) & 192) ==  128
+		   && (((unsigned char)m_s[p+2]) & 192) ==  128
+		   && (((unsigned char)m_s[p+3]) & 192) ==  128
+		;
+	default:
+	    return false;
 	}
     }
 
     // Get character byte length at specified position. Returns 0 for error.
-    inline int get_cl(string::size_type p) const 
+    inline int get_cl(std::string::size_type p) const 
     {
 	unsigned int z = (unsigned char)m_s[p];
 	if (z <= 127) {
@@ -200,7 +225,7 @@ private:
     }
 
     // Compute value at given position. No error checking.
-    inline unsigned int getvalueat(string::size_type p, int l) const
+    inline unsigned int getvalueat(std::string::size_type p, int l) const
     {
 	switch (l) {
 	case 1: 
@@ -248,7 +273,6 @@ private:
 #ifdef UTF8ITER_CHECK
 	    assert(l <= 4);
 #endif
-	    m_error = true;
 	    return (unsigned int)-1;
 	}
     }
